/* /////////////////////////////////////////////////////////////////////////////
 * File:		exception.d
 *
 * Purpose:		Win32 exception base type
 *
 * Created		15th September 2003
 * Updated:		15th September 2003
 *
 * Copyright:	Synesis Software Pty Ltd, (c) 2002. All rights reserved.
 *
 * Home:		http://www.synesis.com.au/software
 *
 * ////////////////////////////////////////////////////////////////////////// */



/** \file synsoft/win32/exception.d This file contains Win32 exception class(es) */

/* ////////////////////////////////////////////////////////////////////////// */

module synsoft.win32.exception;

/* ////////////////////////////////////////////////////////////////////////// */

import synsoft.win32.types;
import string;

/* ////////////////////////////////////////////////////////////////////////// */

/// \defgroup group_synsoft_win32_exception synsoft.win32.exception
/// \ingroup group_synsoft_win32
/// \brief This library provides Win32 exception facilities

/* ////////////////////////////////////////////////////////////////////////// */

/// This class is thrown by \c synsoft.win32.* classes
///
/// \ingroup group_synsoft_win32_exception

class Win32Exception
	: Exception
{
/// \name Construction
//@{
public:
	/// \brief Creates an instance of the exception
	///
	/// \param message The message associated with the exception
	this(char[] message);

	/// \brief Creates an instance of the exception, with the given 
	///
	/// \param message The message associated with the exception
	/// \param error The Win32 error number associated with the exception
	this(char[] message, int error);

//@}

/// \name Attributes
//@{
public:
	/// Returns the Win32 error code associated with the failure
	int propget_Error();

	/// Converts the error into 
	char[] LookupError(char[] moduleName);

//@}
}

////////////////////////////////////////////////////////////////////////////////
